@@ -16,10 +16,9 @@ decimal_date.default <- function(date){
   if(any(!inherits(date, c("POSIXt", "POSIXct", "POSIXlt", "Date"))))
     stop("date(s) not in POSIXt or Date format")
 
-  date <- force_tz(as.POSIXlt(date), tzone = "UTC")
   Y <- year(date)
-  start <- make_datetime(Y, 1L, 1L)
-  end <- make_datetime(Y + 1L, 1L, 1L)
+  start <- make_datetime(Y, 1L, 1L, tz = tz(date))
+  end <- make_datetime(Y + 1L, 1L, 1L, tz = tz(date))
   sofar <- as.numeric(difftime(date, start, units = "secs"))
   total <- as.numeric(difftime(end, start, units = "secs"))
   Y + sofar/total
@@ -48,16 +47,13 @@ decimal_date.its <- function(date)
 #' date <- ymd("2009-02-10")
 #' decimal <- decimal_date(date)  # 2009.11
 #' date_decimal(decimal) # "2009-02-10 UTC"
-date_decimal <- function(decimal, tz = NULL) {
+date_decimal <- function(decimal, tz = "UTC") {
   Y <- trunc(decimal)
   ## parsing is much faster than updating
-  start <- make_datetime(Y, 1L, 1L)
-  end <- make_datetime(Y + 1L, 1L, 1L)
+  start <- make_datetime(Y, 1L, 1L, tz = tz)
+  end <- make_datetime(Y + 1L, 1L, 1L, tz = tz)
   seconds <- as.numeric(difftime(end, start, units = "secs"))
   frac <- decimal - Y
   end <- start + seconds*frac
-  if (!is.null(tz))
-    force_tz(end, tz)
-  else
-    end
+  return(end)
 }
