@@ -42,10 +42,10 @@
 ##' sf <- stamp("Created on Sunday, Jan 1, 1999 3:34 pm")
 ##' sf(D)
 ##' stamp("Jan 01")(D)
-##' stamp("Sunday, May 1, 2000")(D)
+##' stamp("Sunday, May 1, 2000", locale = "en_US")(D)
 ##' stamp("Sun Aug 5")(D) #=> "Sun Aug 04" "Sat Aug 04" "Fri Aug 04" "Thu Aug 04" "Wed Aug 03"
 ##' stamp("12/31/99")(D)              #=> "06/09/11"
-##' stamp("Sunday, May 1, 2000 22:10")(D)
+##' stamp("Sunday, May 1, 2000 22:10", locale = "en_US")(D)
 ##' stamp("2013-01-01T06:00:00Z")(D)
 ##' stamp("2013-01-01T00:00:00-06")(D)
 ##' stamp("2013-01-01T00:00:00-08:00")(force_tz(D, "America/Chicago"))
@@ -53,7 +53,7 @@ stamp <- function(x, orders = lubridate_formats,
                   locale = Sys.getlocale("LC_TIME"), quiet = FALSE){
 
   fmts <- unique(guess_formats(x, orders, locale))
-  if( is.null(fmts) ) stop( "Couldn't quess formats of: ", x)
+  if( is.null(fmts) ) stop( "Couldn't guess formats of: ", x)
   if( length(fmts) == 1L ){
     FMT <- fmts[[1]]
   }else{
